RGBDSensorClient_refactor {#master}
-------------------------

## Bug Fixes

### Devices

#### `RGBDSensorClient`

* The device no longer crashes when no image was received yet (#2349).
* The timestamp is now correct.
